@@ -138,24 +138,6 @@ class _EventData(dtoutputs.OutputBase):
         dtlog.warning('Skipping unknown event type {}.'.format(event_type))
         return None, None
 
-    def _celsius_to_fahrenheit(self, celsius: float) -> float:
-        """
-        Converts Celsius temperature value to Fahrenheit.
-
-        Parameters
-        ----------
-        celsius : float
-            Temperature value in Celsius.
-
-        Returns
-        -------
-        fahrenheit : float
-            Temperature value in Fahrenheit if Celsius is not None.
-
-        """
-
-        return (celsius * (9/5)) + 32
-
 
 class Touch(_EventData):
     """
@@ -240,6 +222,8 @@ class Temperature(_EventData):
         Temperature value in Celsius.
     fahrenheit : float
         Temperature value in Fahrenheit.
+    samples : list[TemperatureSample]
+        Temperature values sampled over a single heartbeat.
     timestamp : datetime
         Timestamp of when the event was received by a Cloud Connector.
 
@@ -247,6 +231,7 @@ class Temperature(_EventData):
 
     def __init__(self,
                  celsius: float,
+                 samples: Optional[list] = None,
                  timestamp: Optional[datetime | str] = None,
                  ) -> None:
         """
@@ -257,6 +242,8 @@ class Temperature(_EventData):
         ----------
         celsius : float
             Temperature value in Celsius.
+        samples : list[TemperatureSample]
+            Temperature values sampled over a single heartbeat.
         timestamp : datetime, str, optional
             Timestamp in either datetime or string iso8601 format
             (i.e. yyyy-MM-ddTHH:mm:ssZ).
@@ -265,7 +252,8 @@ class Temperature(_EventData):
 
         # Set parameter attributes.
         self.celsius: float = celsius
-        self.fahrenheit: float = self._celsius_to_fahrenheit(celsius)
+        self.samples: Optional[list] = samples
+        self.fahrenheit: float = dttrans._celsius_to_fahrenheit(celsius)
         self.timestamp: Optional[datetime | str] = timestamp
 
         # Inherit parent _EventData class init with repacked data dictionary.
@@ -274,12 +262,14 @@ class Temperature(_EventData):
     def __repr__(self) -> str:
         string = '{}.{}('\
             'celsius={}, '\
+            'samples={}, '\
             'timestamp={}'\
             ')'
         return string.format(
             self.__class__.__module__,
             self.__class__.__name__,
             self.celsius,
+            self.samples,
             repr(dttrans.to_iso8601(self.timestamp)),
         )
 
@@ -300,9 +290,18 @@ class Temperature(_EventData):
 
         """
 
+        # Convert samples dictionaries to TemperatureSample objects.
+        sample_objs = []
+        for sample in data['samples']:
+            sample_objs.append(TemperatureSample(
+                celsius=sample['value'],
+                timestamp=sample['sampleTime'],
+            ))
+
         # Construct the object with unpacked parameters.
         obj = cls(
             celsius=data['value'],
+            samples=sample_objs,
             timestamp=data['updateTime'],
         )
 
@@ -315,11 +314,88 @@ class Temperature(_EventData):
         data: dict = dict()
         if self.celsius is not None:
             data['value'] = self.celsius
+        if self.samples is not None:
+            data['samples'] = [s._raw for s in self.samples]
         if self.timestamp is not None:
             data['updateTime'] = self.timestamp
         return data
 
 
+class TemperatureSample(dtoutputs.OutputBase):
+    """
+    Represents a single temperature event sample from a heartbeat period.
+
+    Attributes
+    ----------
+    celsius : float
+        Temperature value in Celsius.
+    fahrenheit : float
+        Temperature value in Fahrenheit.
+    timestamp : datetime
+        Interpolated inter-heartbeat timestamp.
+
+    """
+
+    def __init__(self,
+                 celsius: float,
+                 timestamp: datetime | str,
+                 ) -> None:
+        """
+        Constructs the TemperatureSample object. The `fahrenheit` attribute is
+        calculated from the provided `celsius` parameter.
+
+        Parameters
+        ----------
+        celsius : float
+            Temperature value in Celsius.
+        timestamp : datetime, str, optional
+            Timestamp in either datetime or string iso8601 format
+            (i.e. yyyy-MM-ddTHH:mm:ssZ).
+
+        """
+
+        # Set parameter attributes.
+        self.celsius: float = celsius
+        self.fahrenheit: float = dttrans._celsius_to_fahrenheit(celsius)
+        self.timestamp = dttrans.to_datetime(timestamp)
+
+        # Inherit parent class.
+        dtoutputs.OutputBase.__init__(self, self.__repack())
+
+    def __repr__(self) -> str:
+        string = '{}.{}('\
+            'celsius={}, '\
+            'timestamp={}'\
+            ')'
+        return string.format(
+            self.__class__.__module__,
+            self.__class__.__name__,
+            self.celsius,
+            repr(dttrans.to_iso8601(self.timestamp)),
+        )
+
+    @classmethod
+    def _from_raw(cls, data: dict) -> TemperatureSample:
+        # Construct the object with unpacked parameters.
+        obj = cls(
+            celsius=data['value'],
+            timestamp=data['sampleTime'],
+        )
+
+        # Inherit parent class.
+        dtoutputs.OutputBase.__init__(obj, data)
+
+        return obj
+
+    def __repack(self) -> dict:
+        data: dict = dict()
+        if self.celsius is not None:
+            data['value'] = self.celsius
+        if self.timestamp is not None:
+            data['sampleTime'] = dttrans.to_iso8601(self.timestamp)
+        return data
+
+
 class ObjectPresent(_EventData):
     """
     Represents the data found in an objectPresent event.
@@ -415,7 +491,7 @@ class Humidity(_EventData):
     ----------
     temperature : float
         Temperature value in Celsius.
-    humidity : float
+    relative_humidity : float
         Relative humidity in percent.
     timestamp : datetime
         Timestamp of when the event was received by a Cloud Connector.
@@ -424,7 +500,7 @@ class Humidity(_EventData):
 
     def __init__(self,
                  celsius: float,
-                 humidity: float,
+                 relative_humidity: float,
                  timestamp: Optional[datetime | str] = None,
                  ):
         """
@@ -434,7 +510,7 @@ class Humidity(_EventData):
         ----------
         temperature : float
             Temperature value in Celsius.
-        humidity : float
+        relative_humidity : float
             Relative humidity in percent.
         timestamp : datetime, str, optional
             Timestamp in either datetime or string iso8601 format
@@ -444,8 +520,8 @@ class Humidity(_EventData):
 
         # Set parameter attributes.
         self.celsius: float = celsius
-        self.fahrenheit: float = self._celsius_to_fahrenheit(celsius)
-        self.humidity: float = humidity
+        self.fahrenheit: float = dttrans._celsius_to_fahrenheit(celsius)
+        self.relative_humidity: float = relative_humidity
         self.timestamp: Optional[datetime | str] = timestamp
 
         # Inherit parent _EventData class init with repacked data dictionary.
@@ -454,14 +530,14 @@ class Humidity(_EventData):
     def __repr__(self) -> str:
         string = '{}.{}('\
             'celsius={}, '\
-            'humidity={}, '\
+            'relative_humidity={}, '\
             'timestamp={}'\
             ')'
         return string.format(
             self.__class__.__module__,
             self.__class__.__name__,
             self.celsius,
-            self.humidity,
+            self.relative_humidity,
             repr(dttrans.to_iso8601(self.timestamp)),
         )
 
@@ -485,7 +561,7 @@ class Humidity(_EventData):
         # Construct the object with unpacked parameters.
         obj = cls(
             celsius=data['temperature'],
-            humidity=data['relativeHumidity'],
+            relative_humidity=data['relativeHumidity'],
             timestamp=data['updateTime'],
         )
 
@@ -498,8 +574,8 @@ class Humidity(_EventData):
         data: dict = dict()
         if self.celsius is not None:
             data['temperature'] = self.celsius
-        if self.humidity is not None:
-            data['relativeHumidity'] = self.humidity
+        if self.relative_humidity is not None:
+            data['relativeHumidity'] = self.relative_humidity
         if self.timestamp is not None:
             data['updateTime'] = self.timestamp
         return data
